/**
 *   This file is a part of the KDE Project
 *   Copyright (C) 2017 Dan Leinir Turthra Jensen <admin@leinir.dk>
 *
 *   This program is free software; you can redistribute it and/or modify
 *   it under the terms of the GNU Library/Lesser General Public License
 *   version 2, or (at your option) any later version, as published by the
 *   Free Software Foundation
 *
 *   This program is distributed in the hope that it will be useful,
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *   GNU General Public License for more details
 *
 *   You should have received a copy of the GNU Library/Lesser General Public
 *   License along with this program; if not, write to the
 *   Free Software Foundation, Inc.,
 *   51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
 */

import QtQuick 2.5
import Qt.labs.presentation 1.0

LoopSlide {
    id: root;
    property var images: [];
    timeout: imageTimeout * images.length;
    property int imageTimeout: 4000
    x: parent.width * 0.02;
    y: parent.height * 0.02;
    width: parent.width * 0.96;
    height: parent.height * 0.96;
    contentWidth: width * 0.33
    delayPoints: true;

    onVisibleChanged: {
        if(visible) {
            root._pointCounter = 0;
            pathTimer.restart();
        }
        else {
            pathTimer.stop();
        }
    }
    Timer {
        id: pathTimer;
        running: false;
        repeat: false;
        interval: imageTimeout;
        onTriggered: {
            if(root._pointCounter < images.length - 1) {
                root._advance();
                pathTimer.restart();
            }
        }
    }
    PathView {
        id: path;
        model: root.images;
        currentIndex: root._pointCounter;
        preferredHighlightBegin: 0.5;
        preferredHighlightEnd: 0.5;
        pathItemCount: 2
        delegate: Image {
            height: root.height;
            width: root.width * 0.67;
            source: modelData;
            fillMode: Image.PreserveAspectFit;
            opacity: PathView.imageAlpha ? PathView.imageAlpha : 0;
            scale: PathView.imageScale ? PathView.imageScale : 1;
        }
        path: Path {
            startX: root.width; startY: root.height + root.y
            PathAttribute { name: "imageAlpha"; value: 0 }
            PathAttribute { name: "imageScale"; value: 2 }
            PathCurve { x: root.width * 0.67; y: root.height / 2 }
            PathAttribute { name: "imageAlpha"; value: 1 }
            PathAttribute { name: "imageScale"; value: 1 }
            PathCurve { x: root.width; y: -root.y; }
            PathAttribute { name: "imageAlpha"; value: 0 }
            PathAttribute { name: "imageScale"; value: 0 }
        }
    }
}
