/**
 *   This file is a part of the KDE Project
 *   Copyright (C) 2018 Dan Leinir Turthra Jensen <admin@leinir.dk>
 *
 *   This program is free software; you can redistribute it and/or modify
 *   it under the terms of the GNU Library/Lesser General Public License
 *   version 2, or (at your option) any later version, as published by the
 *   Free Software Foundation
 *
 *   This program is distributed in the hope that it will be useful,
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *   GNU General Public License for more details
 *
 *   You should have received a copy of the GNU Library/Lesser General Public
 *   License along with this program; if not, write to the
 *   Free Software Foundation, Inc.,
 *   51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
 */

import QtQuick 2.5
import Qt.labs.presentation 1.0

FancyKDEPresentation {
    id: presentation
    width: 1280
    height: 720
    fontFamily: "Lato"

    SlideCounter {}
    Clock {}

    ImageSlide {
        image: "images/QtWC2017/KDELightningSticker.png"
    }

    ImageSlide {
        image: "images/power-up.png"
    }

    Slide {
        textFormat: Text.RichText
        fontScale: 2
        centeredText: "<b>Get Hot New Stuff Quick(ly)</b><br><br>

                       or<br><br>Modernising the<br>KNewStuff Framework"
    }

    Slide {
        fontScale: 2
        centeredText: "Your Host"
    }

    MultiImageSlide {
        title: "Dan Leinir Turthra Jensen"
        imageTimeout: 20000
        delayPoints: true
        contentWidth: width * 0.4
        content: [
            "Your Host:
- Dan Leinir Turthra Jensen
- MSc in Software Construction, specialised in Game and Engine Programming
- Member of KDE community since 2002, Akademy 2007
- Calligra and Gluon team member
- Employee of Blue Systems",
            "Sometimes a bird"
        ]
        images: [
            "images/personal/leinir.jpg",
            "images/personal/birdie.jpg"
        ]
    }

// ######################################################################################
    Slide {
        fontScale: 2
        centeredText: "First, Some History"
    }

    Slide {
        delayPoints: true
        title: "Frameworks"
        content: [
            "Attica
Job based wrapper for OCS",
            "KNewStuffCore
UI-less convenience for using fetching and installing content
(both Attica and static XML)",
            "KNewStuff
Qt Widgets based UI on top of KNewStuffCore",
            "KNewStuffQuick
Very simple Qt Quick based UI (List and Item)"
        ]
    }

    Slide {
        title: "Store"
        delayPoints: true
        content: [
            "Previously built on hive01 framework",
            "New version built using framework developed by Pling and released as free software",
            "Now hosted by legally separate but KDE controlled entity
(because user data protection)",
            "Much more control for KDE"
        ]
    }

// ######################################################################################
    Slide {
        fontScale: 2
        centeredText: "New Shinies"
    }

    MultiImageSlide {
        title: "Equivalence"
        imageTimeout: 120000
        delayPoints: true
        fontScale: 0.8
        content: [
            "Button
Like KNS3::Button. Simplest integration point, most common use.",
            "Dialog/DialogContent
Like KNS3::DownloadDialog/Widget. Commonly used when launched from a menu.",
            "QuestionAsker and QuickQuestionListener
Like WidgetQuestionListener. How would we ask the important questions without?",
            "NewStuffList/Item
For simple integration with more power than Button. Updated with new shininess."
        ]
        images: [
            "images/screenshots/button.png",
            "images/screenshots/dialog.png",
            "images/screenshots/questionasker.png",
            "images/screenshots/peruse.png"
        ]
    }

    MultiImageSlide {
        title: "Now With More Shiny"
        imageTimeout: 120000
        delayPoints: true
        fontScale: 0.8
        content: [
            "Page
Because dialogues are so last decade
Just like that put-down",
            "Entry details
Much more detail, much more space",
            "Comments
Because comments (no, really, how were they missing?!)",
            "Author
For super-tight and pervasive integrationingness"
        ]
        images: [
            "images/screenshots/test-tool.png",
            "images/screenshots/entry-details.png",
            "images/screenshots/comments.png",
            "images/screenshots/author.png"
        ]
    }

// ######################################################################################
    Slide {
        fontScale: 2
        centeredText: "A Touch of Code"
    }

    CodeSlide {
        title: "NewStuff.Button"
        code:
"import org.kde.newstuff 1.62

NewStuff.Button {
    id: newStuffButton
    QtLayouts.Layout.fillWidth: true
    configFile: \"knsrcfilename\"
}"
    }

    CodeSlide {
        title: "NewStuff.List"
        code:
"import org.kde.newstuff 1.0

NewStuff.NewStuffList {
    configFile: peruseConfig.newstuffLocation;
    onDownloadedItemClicked: {
        if(Array.isArray(installedFiles) && installedFiles.length > 0) {
            applicationWindow().showBook(installedFiles[0], 0);
        }
        else if(installedFiles.length > 0) {
            applicationWindow().showBook(installedFiles, 0);
        }
    }
}"
    }

    CodeSlide {
        title: "NewStuff.Page"
        code:
"import org.kde.kirigami 2.7 as Kirigami
import org.kde.newstuff 1.62 as NewStuff

Kirigami.ApplicationWindow {
    id: root;
    title: \"KNewStuff Dialog\"
    // [...]
    Component {
        id: mainPageComponent
        NewStuff.Page { }
    }
    Component.onCompleted: {
        // Delay your engine initialisation
        pageStack.push(mainPageComponent, { configFile: knsrcfile } );
    }
    // [...]
}"
    }

    CodeSlide {
        title: "NewStuff.Author"
        code:
"import org.kde.kirigami 2.7 as Kirigami
import org.kde.newstuff 1.62 as NewStuff

NewStuff.Author {
    engine: NewStuff.Engine { configFile: \"peruse.knsrc\" }
    // providerId: \"https://api.kde-look.org/ocs/v1/\"
    username: \"leinir\"
}

Image {
    source: component.commentAuthor.avatarUrl
}
Kirigami.UrlButton {
    url: component.commentAuthor.homepage === \"\"
    text: component.commentAuthor.name
}"
    }

// ######################################################################################
    Slide {
        fontScale: 2
        centeredText: "Demo Time"
    }

// ######################################################################################
    Slide {
        fontScale: 2
        centeredText: "Questions?"
    }

    Slide {
        fontScale: 3
        centeredText: "Thank You!"
    }

//     MultiImageSlide {
//         content: [
//             "Switch to one of Plasma Mobile's apps",
//             "We got dialers",
//             "We got maps",
//             "We got pictures",
//             "Discover more apps with Discover",
//             "Or build your own with Kirigami"
//         ]
//         images: [
//             "images/plasma-phone/plasma-phone-switcher.png",
//             "images/plasma-phone/plasma-phone-phone.png",
//             "images/plasma-phone/plasma-phone-apps-maps.png",
//             "images/plasma-phone/plasma-phone-apps-pictures.png",
//             "images/plasma-phone/plasma-phone-apps-discover.png",
//             "images/plasma-phone/plasma-phone-kirigami.png"
//         ]
//     }
// 
//     VideoSlide {
//         video: "videos/stage-demo.mp4"
//     }
}
